+++
title = "DTR Repository API"
description = "Docker Trusted Registry 1.3 Repository API"
keywords = ["API, Docker, index, REST, documentation, Docker Trusted Registry, registry"]
weight = 65
[menu.main]
parent = "smn_dtrapi"
+++

# Docker Trusted Registry 1.3 Repositories

## List Repositories in a Namespace

`GET /api/v0/repositories/{namespace}`

```bash
$ curl -v --user admin:password --insecure -X GET https://dtr.domain.com/api/v0/repositories/engineering
```

Example Response:

```json
{
  "repositories": [
    {
      "id": 17,
      "namespace": "don",
      "name": "public-app",
      "shortDescription": "An Open-Source Retro Turboencabulator",
      "longDescription": "For a number of years now, work has been proceeding in order to bring perfection to the crudely conceived idea of a transmission that would not only supply inverse reactive current for use in unilateral phase detractors, but would also be capable of automatically synchronizing cardinal grammeters. Such an instrument is the turbo-encabulator.\nNow basically the only new principle involved is that instead of power being generated by the relative motion of conductors and fluxes, it's produced by the modial interaction of magneto-reluctance and capacitive diractance.",
      "visibility": "public",
      "status": "ok"
    },
    {
      "id": 32,
      "namespace": "don",
      "name": "private-app",
      "shortDescription": "A Closed-Source Retro Turboencabulator",
      "longDescription": "The original machine had a base plate of pre-famulated amulite surmounted by a malleable logarithmic casing in such a way that the two spurving bearings were in a direct line with the panametric fam. The latter consisted simply of six hydrocoptic marzlevanes, so fitted to the ambifacient lunar waneshaft that side fumbling was effectively prevented.\nThe main winding was of the normal lotus-o-delta type placed in panendermic semi-boloid slots of the stator, every seventh conductor being connected by a non-reversible termie pipe to the differential girdle spring on the \"up\" end of the grammies.\nThe turbo-encabulator has now reached a high level of development, and it’s being successfully used in the operation of novertrunnions.",
      "visibility": "private",
      "status": "ok"
    }
  ]
}
```

**Authorization**

Client must be authenticated as any active user in the system. Results will be
filtered to only those repositories visible to the client.

**Status Codes**

- *404* no such namespace.
- *200* success.

## View Details of a Repository

`GET /api/v0/repositories/{namespace}/{reponame}`

```bash
$ curl -v --user admin:password --insecure -X GET https://dtr.domain.com/api/v0/repositories/engineering/public-app
```

Example Response:

```json
{
  "id": 17,
  "namespace": "don",
  "name": "public-app",
  "shortDescription": "An Open-Source Retro Turboencabulator",
  "longDescription": "For a number of years now, work has been proceeding in order to bring perfection to the crudely conceived idea of a transmission that would not only supply inverse reactive current for use in unilateral phase detractors, but would also be capable of automatically synchronizing cardinal grammeters. Such an instrument is the turbo-encabulator.\nNow basically the only new principle involved is that instead of power being generated by the relative motion of conductors and fluxes, it's produced by the modial interaction of magneto-reluctance and capacitive diractance.",
  "visibility": "public",
  "status": "ok"
}
```

**Authorization**

Client must be authenticated as a user who has visibility to the repository.

**Status Codes**

- *404* no such repository namespace exists or client not authorized.
- *200* success.

## Create a Repository

`POST /api/v0/repositories/{namespace}`

```bash
$ curl -v --user admin:password --insecure -X POST --data '{"name":"my-app"}' --header "Content-type: application/json" https://dtr.domain.com/api/v0/repositories/engineering
```

If you don't specify the `visibility`, option, it will default to `private`.

Example Request:

```http
POST /api/v0/repositories/alice HTTP/1.1
Content-Type: application/json

{
  "name": "my-app",
  "shortDescription": "My cool Docker application",
  "longDescription": "This application does a bunch of cool stuff",
  "visibility": "private"
}
```

Example Response:

```json
{
  "id": 17,
  "namespace": "alice",
  "name": "my-app",
  "shortDescription": "My cool Docker application",
  "longDescription": "This application does a bunch of cool stuff",
  "visibility": "private",
  "status": "ok"
}
```

**Authorization**

Client must be authenticated as a user who has `admin` access to the
repository namespace (i.e., user owns the repo or is a member of a team with 'admin' level access to the organization's namespace of repositories).

**Status Codes**

- *403* the client is not authorized.
- *400* invalid repository details.
- *201* success.

## Update Details of a Repository

`PATCH /api/v0/repositories/{namespace}/{reponame}`

```bash
$ curl -v --user admin:password --insecure -X PATCH --data '{"shortDescription":"slightly out of date"}' --header "Content-type: application
/json" https://192.168.18.129/api/v0/repositories/engineering/public-app
```

Any fields not preset in the body of this request will retain their existing value.
You cannot rename a repository using this API - the "name" field is ignored.

Example Request:

```
PATCH /api/v0/repositories/alice/my-app HTTP/1.1
Content-Type: application/json

{
  "shortDescription": "My Cool Docker Retro Turboencablutator",
  "longDescription": "For a number of years now, work has been proceeding in order to bring perfection to the crudely conceived idea of a server application that would not only supply inverse reactive current for use in unilateral phase detractors, but would also be capable of automatically synchronizing cardinal grammeters. Such an application is this turbo-encabulator.",
  "visibility": "public"
}
```

Example Response:

```json
{
  "id": 17,
  "namespace": "alice",
  "name": "my-app",
  "shortDescription": "My Cool Docker Retro Turboencablutator",
  "longDescription": "For a number of years now, work has been proceeding in order to bring perfection to the crudely conceived idea of a server application that would not only supply inverse reactive current for use in unilateral phase detractors, but would also be capable of automatically synchronizing cardinal grammeters. Such an application is this turbo-encabulator.",
  "visibility": "public",
  "status": "ok"
}
```

**Authorization**

Client must be authenticated as a user who has `admin` access to the
repository (i.e., user owns the repo or is a member of a team with 'admin' level access to the organization's repository).

**Status Codes**

- *403* the client is not authorized.
- *400* invalid repository details.
- *200* success.

## Remove a Repository (removes db record only)

`DELETE /api/v0/repositories/{namespace}/{reponame}`

```bash
curl -v --user admin:password -X DELETE https://dtr.domain.com/api/v0/repositories/engineering/public-app
```

**Authorization**

Client must be authenticated as a user who has `admin` access to the
repository (i.e., user owns the repo or is a member of a team with 'admin' level access to the organization's repository).

**Status Codes**

- *403* the client is not authorized.
- *204* (`No Content`) success - or repository does not exist.
