+++
title = "DTR User Repository API"
description = "Docker Trusted Registry 1.3 User-Owned Repository Acces"
keywords = ["API, Docker, index, REST, documentation, Docker Trusted Registry, registry"]
weight = 66
[menu.main]
parent = "smn_dtrapi"
+++

# Docker Trusted Registry 1.3 User-Owned Repository Access

User accounts can be granted `read-only`, `read-write`, or `admin` level access
to any repository owned by another user account.

**`read-only`**

- user can pull from the repository

**`read-write`**

- user can pull from the repository
- user can push to the repository

**`admin`**

- user can pull from the repository
- user can push to the repository
- user can manage other users' access to the repository

## List Users Granted Access to a User-Owned Repository

`GET /api/v0/repositories/{namespace}/{reponame}/userAccess`

```bash
curl -v --user josh:password --insecure https://dtr.domain.com/api/v0/repositories/josh/public-app/userAccess
```

Example Response:

```json
{
  "repository": {
    "id": 28,
    "namespace": "josh",
    "name": "public-app",
    "shortDescription": "An Open-Source Retro Turboencabulator",
    "longDescription": "For a number of years now, work has been proceeding in order to bring perfection to the crudely conceived idea of a transmission that would not only supply inverse reactive current for use in unilateral phase detractors, but would also be capable of automatically synchronizing cardinal grammeters. Such an instrument is the turbo-encabulator.\nNow basically the only new principle involved is that instead of power being generated by the relative motion of conductors and fluxes, it's produced by the modial interaction of magneto-reluctance and capacitive diractance.",
    "visibility": "public",
    "status": "ok"
  },
  "userAccessList": [
    {
      "accessLevel": "read-write",
      "user": {
        "id": 14,
        "type": "user",
        "name": "brian",
        "isActive": true
      }
    },
    {
      "accessLevel": "read-write",
      "user": {
        "id": 6,
        "type": "user",
        "name": "don",
        "isActive": true
      }
    }
  ]
}
```

**Authorization**

Client must be authenticated as a user which has 'admin' level access to the
repository.

**Status Codes**

- *404* the repository is not visible to the client.
- *400* the repository is not owned by a user.
- *403* the client is not authorized.
- *200* success.

## Set a User's Access to a User-Owned Repository

`PUT /api/v0/repositories/{namespace}/{reponame}/userAccess/{grantee}`

```bash
curl -v --user josh:password --insecure -X PUT --header "Content-type: application/json" --data '{"accessLevel":"read-write"}' https://dtr.domain.com/api/v0/repositories/alice/public-app/userAccess/brian
```

Example Request:

```http
PUT /api/v0/repositories/josh/public-app/userAccess/brian HTTP/1.1
Content-Type: application/json

{
  "accessLevel": "read-write",
}
```

Example Response:

```json
{
  "accessLevel": "read-write",
  "user": {
    "id": 14,
    "type": "user",
    "name": "brian",
    "isActive": true
  },
  "repository": {
    "id": 28,
    "namespace": "josh",
    "name": "public-app",
    "shortDescription": "An Open-Source Retro Turboencabulator",
    "longDescription": "For a number of years now, work has been proceeding in order to bring perfection to the crudely conceived idea of a transmission that would not only supply inverse reactive current for use in unilateral phase detractors, but would also be capable of automatically synchronizing cardinal grammeters. Such an instrument is the turbo-encabulator.\nNow basically the only new principle involved is that instead of power being generated by the relative motion of conductors and fluxes, it's produced by the modial interaction of magneto-reluctance and capacitive diractance.",
    "visibility": "public",
    "status": "ok"
  }
}
```

**Authorization**

Client must be authenticated as a user which has 'admin' level access to the
repository.

**Status Codes**

- *404* the repository is not visible to the client.
- *400* repository is not owned by a user.
- *403* the client is unauthorized.
- *200* success.

## Revoke a User's Access to a User-Owned Repository

`DELETE /api/v0/repositories/{namespace}/{reponame}/userAccess/{grantee}`

```bash
$ curl -v --user josh:password --insecure -X DELETE https://dtr.domain.com/api/v0/repositories/josh/public-app/userAccess/user
```

**Authorization**

Client must be authenticated as a user which has 'admin' level access to the
repository.

**Status Codes**

- *404* the repository is not visible to the client.
- *400* the repository is not owned by a user.
- *403* the client is not authorized.
- *204* (`No Content`) success - or user is not in the access list.
